@@ -1,6 +1,6 @@
 ;;; mct.el --- Minibuffer Confines Transcended -*- lexical-binding: t -*-
 
-;; Copyright (C) 2021-2025  Free Software Foundation, Inc.
+;; Copyright (C) 2021-2026  Free Software Foundation, Inc.
 
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
@@ -286,7 +286,9 @@ completion category is set to sort by history)."
 
 (defun mct--passlist-p ()
   "Return non-nil if symbol is in the `mct-completion-passlist'."
-  (mct--symbol-in-list mct-completion-passlist))
+  (or (mct--symbol-in-list mct-completion-passlist)
+      (when (fboundp 'completion-category-get)
+        (completion-category-get (mct--completion-category) 'eager-display))))
 
 (defun mct--blocklist-p ()
   "Return non-nil if symbol is in the `mct-completion-blocklist'."
@@ -316,7 +318,7 @@ This function can be used as the value of the user option
      (or (funcall mct-sort-alpha-function string1 string2)
          (< (length string1) (length string2))))))
 
-(defalias 'mct-sort-by-alpha-length 'mct-sort-by-alpha-then-by-length
+(defalias 'mct-sort-by-alpha-length #'mct-sort-by-alpha-then-by-length
   "Alias for `mct-sort-by-alpha-then-by-length'.")
 
 ;; Based on `minibuffer-sort-by-history' from Emacs 30.
@@ -341,7 +343,7 @@ Also remove the implicit directories . and .. from the COMPLETIONS."
   (nconc (seq-filter (lambda (x) (string-suffix-p "/" x)) completions)
          (seq-remove (lambda (x) (string-suffix-p "/" x)) completions)))
 
-(defalias 'mct-sort-directories-then-files 'mct-sort-by-directory-then-by-file
+(defalias 'mct-sort-directories-then-files #'mct-sort-by-directory-then-by-file
   "Alias for `mct-sort-by-directory-then-by-file'.")
 
 (defun mct--sort-multi-category-get-function (function-and-category)
@@ -367,7 +369,7 @@ Do it in accordance with the user option `mct-sort-by-command-or-category'."
 ;;;; Basics of intersection between minibuffer and Completions buffer
 
 (defface mct-highlight-candidate
-  '((t :inherit highlight :extend nil))
+  '((t :inherit highlight :extend t))
   "Face for current candidate in the Completions buffer."
   :group 'mct)
 
@@ -406,7 +408,7 @@ Can be used in `mct-completion-window-size'."
 
 (define-obsolete-function-alias
   'mct--frame-height-fraction
-  'mct-frame-height-third
+  #'mct-frame-height-third
   "1.0.0")
 
 (defun mct--height (param)
@@ -1154,7 +1156,7 @@ Do this under any of the following conditions:
 
 (define-obsolete-function-alias
   'mct-minibuffer-mode
-  'mct-mode
+  #'mct-mode
   "1.0.0")
 
 (make-obsolete 'mct-region-mode nil "1.0.0")
